#
# Copyright (c) 2008-2018 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'

from zope.interface import Interface

from pyams_content.interfaces import IBaseContent
from pyams_content.shared.common.interfaces import IWfSharedContent
from pyams_default_theme.interfaces import IContentDate, IContentNavigationTitle, \
    IContentTag
from pyams_i18n.interfaces import II18n
from pyams_skin.layer import IPyAMSLayer
from pyams_utils.adapter import ContextRequestViewAdapter, adapter_config
from pyams_utils.date import SH_DATE_FORMAT, format_date
from pyams_utils.interfaces.tales import ITALESExtension
from pyams_workflow.interfaces import IWorkflowPublicationInfo


@adapter_config(context=(IBaseContent, IPyAMSLayer), provides=IContentNavigationTitle)
def shared_content_navigation_title(context, request):
    """Default content navigation title adapter"""
    return II18n(context).query_attribute('title', request=request)


@adapter_config(name='pyams_title',
                context=(Interface, Interface, Interface),
                provides=ITALESExtension)
class PyAMSContentTitleTALESExtension(ContextRequestViewAdapter):
    """PyAMS content title TALES extension"""

    def render(self, context=None):
        if context is None:
            context = self.context
        return self.request.registry.queryMultiAdapter((context, self.request), IContentNavigationTitle)


@adapter_config(context=(IWfSharedContent, IPyAMSLayer), provides=IContentTag)
def shared_content_tag_adapter(context, request):
    """Default shared content tag adapter"""
    translate = request.localizer.translate
    return translate(context.content_name)


@adapter_config(name='pyams_tag',
                context=(Interface, Interface, Interface),
                provides=ITALESExtension)
class PyAMSContentTagTALESExtension(ContextRequestViewAdapter):
    """PyAMS content tag TALES extension"""

    def render(self, context=None):
        if context is None:
            context = self.context
        return self.request.registry.queryMultiAdapter((context, self.request), IContentTag)


@adapter_config(context=(IWfSharedContent, IPyAMSLayer), provides=IContentDate)
def shared_content_date_adapter(context, request):
    """Default shared content date adapter"""
    publication_info = IWorkflowPublicationInfo(context, None)
    if publication_info is not None:
        return format_date(publication_info.visible_publication_date,
                           format=SH_DATE_FORMAT, request=request)


@adapter_config(name='pyams_date',
                context=(Interface, Interface, Interface),
                provides=ITALESExtension)
class PyAMSContentDateTALESExtension(ContextRequestViewAdapter):
    """PyAMS content date TALES extension"""

    def render(self, context=None):
        if context is None:
            context = self.context
        return self.request.registry.queryMultiAdapter((context, self.request), IContentDate)
